@@ -1,6 +1,6 @@
 from landscape import CLIENT_API
 from landscape.lib.persist import Persist
-from landscape.lib.fetch import HTTPCodeError
+from landscape.lib.fetch import HTTPCodeError, PyCurlError
 from landscape.lib.hashlib import md5
 from landscape.schema import Message, Int
 from landscape.broker.config import BrokerConfiguration
@@ -993,7 +993,7 @@ class MessageExchangeTest(LandscapeTest):
         """
         events = []
 
-        def failed_exchange():
+        def failed_exchange(ssl_error=False):
             events.append(None)
 
         self.reactor.call_on("exchange-failed", failed_exchange)
@@ -1001,6 +1001,43 @@ class MessageExchangeTest(LandscapeTest):
         self.exchanger.exchange()
         self.assertEqual([None], events)
 
+    def test_SSL_error_exchanging_causes_failed_exchange(self):
+        """
+        If an SSL error occurs when exchanging, the 'exchange-failed'
+        event should be fired with the optional "ssl_error" flag set to True.
+        """
+        self.log_helper.ignore_errors("Message exchange failed: Failed to "
+                                      "communicate.")
+        events = []
+
+        def failed_exchange(ssl_error):
+            if ssl_error:
+                events.append(None)
+
+        self.reactor.call_on("exchange-failed", failed_exchange)
+        self.transport.responses.append(PyCurlError(60,
+                                                    "Failed to communicate."))
+        self.exchanger.exchange()
+        self.assertEqual([None], events)
+
+    def test_pycurl_error_exchanging_causes_failed_exchange(self):
+        """
+        If an undefined PyCurl error is raised during exchange, (not an SSL
+        error), the 'exchange-failed' event should be fired with the ssl_error
+        flag set to False.
+        """
+        events = []
+
+        def failed_exchange(ssl_error):
+            if not ssl_error:
+                events.append(None)
+
+        self.reactor.call_on("exchange-failed", failed_exchange)
+        self.transport.responses.append(PyCurlError(10,  # Not 60
+                                                    "Failed to communicate."))
+        self.exchanger.exchange()
+        self.assertEqual([None], events)
+
     def test_wb_error_exchanging_records_failure_in_message_store(self):
         """
         If a traceback occurs whilst exchanging, the failure is recorded
