@@ -4,12 +4,14 @@ This module, and specifically L{LandscapeSetupScript}, implements the support
 for the C{landscape-config} script.
 """
 
+from __future__ import print_function
+
+from functools import partial
 import base64
-import time
-import sys
-import os
 import getpass
+import os
 import pwd
+import sys
 
 from StringIO import StringIO
 
@@ -35,6 +37,8 @@ class ImportOptionError(ConfigurationError):
 
 
 def print_text(text, end="\n", error=False):
+    """Display the given text to the user, using stderr if flagged as an error.
+    """
     if error:
         stream = sys.stderr
     else:
@@ -584,104 +588,145 @@ def store_public_key_data(config, certificate_data):
     return key_filename
 
 
-def register(config, on_message=print_text, on_error=sys.exit, reactor=None,
-             max_retries=14):
+def failure(add_result):
+    """Handle a failed communication by recording the kind of failure."""
+    add_result("failure")
+
+
+def exchange_failure(add_result, ssl_error=False):
+    """Handle a failed call by recording if the failure was SSL-related."""
+    if ssl_error:
+        add_result("ssl-error")
+    else:
+        add_result("non-ssl-error")
+
+
+def handle_registration_errors(failure, connector):
+    """Handle invalid credentials.
+
+    The connection to the broker succeeded but the registration itself
+    failed, because of invalid credentials. We need to trap the exceptions
+    so they don't stacktrace (we know what is going on), and try to cleanly
+    disconnect from the broker.
+
+    Note: "results" contains a failure indication already (or will shortly)
+    since the registration-failed signal will fire."""
+    failure.trap(InvalidCredentialsError, MethodCallError)
+    connector.disconnect()
+
+
+def success(add_result):
+    """Handle a successful communication by recording the fact."""
+    add_result("success")
+
+
+def done(ignored_result, connector, reactor):
+    """Clean up after communicating with the server."""
+    connector.disconnect()
+    reactor.stop()
+
+
+def got_connection(add_result, connector, reactor, remote):
+    """Handle becomming connected to a broker."""
+    handlers = {"registration-done": partial(success, add_result),
+                "registration-failed": partial(failure, add_result),
+                "exchange-failed": partial(exchange_failure, add_result)}
+    deferreds = [
+        remote.call_on_event(handlers),
+        remote.register().addErrback(handle_registration_errors, connector)]
+    results = gather_results(deferreds)
+    results.addCallback(done, connector, reactor)
+    return results
+
+
+def got_error(failure, print=print):
+    """...from broker."""
+    print(failure.getTraceback(), file=sys.stderr)
+    raise SystemExit
+
+
+def register(config, reactor=None, connector_factory=RemoteBrokerConnector,
+        got_connection=got_connection, max_retries=14, on_error=None,
+        results=None):
     """Instruct the Landscape Broker to register the client.
 
     The broker will be instructed to reload its configuration and then to
     attempt a registration.
 
-    @param reactor: The reactor to use.  Please only pass reactor when you
-        have totally mangled everything with mocker.  Otherwise bad things
-        will happen.
+    @param reactor: The reactor to use.  This parameter is optional because
+        the client charm does not pass it.
+    @param connector_factory: A callable that accepts a reactor and a
+        configuration object and returns a new remote broker connection.  Used
+        primarily for dependency injection.
+    @param got_connection: The handler to trigger when the remote broker
+        connects.  Used primarily for dependency injection.
     @param max_retries: The number of times to retry connecting to the
         landscape client service.  The delay between retries is calculated
-        by Twisted and increases geometrically.  The default of 14 results in
-        a total wait time of about 70 seconds.
-
-        initialDelay = 0.05
-        factor =  1.62
-        maxDelay = 30
-        max_retries = 14
-
-        0.05 * (1 - 1.62 ** 14) / (1 - 1.62) = 69 seconds
-   """
+        by Twisted and increases geometrically.
+    @param on_error: A callable that will be passed a non-zero positive
+        integer argument in the case that some error occurs.  This is a legacy
+        API provided for use by the client charm.
+    @param results: This parameter provides a mechanism to pre-seed the result
+        of registering.  Used for testing.
+    """
     if reactor is None:
         reactor = LandscapeReactor()
-    exit_with_error = []
-
-    def stop(errors):
-        if not config.ok_no_register:
-            for error in errors:
-                if error is not None:
-                    exit_with_error.append(error)
-        connector.disconnect()
-        reactor.stop()
-
-    def failure():
-        on_message("Invalid account name or "
-                   "registration key.", error=True)
-        return 2
-
-    def success():
-        on_message("System successfully registered.")
-
-    def exchange_failure():
-        on_message("We were unable to contact the server. "
-                   "Your internet connection may be down. "
-                   "The landscape client will continue to try and contact "
-                   "the server periodically.",
-                   error=True)
-        return 2
-
-    def handle_registration_errors(failure):
-        # We'll get invalid credentials through the signal.
-        failure.trap(InvalidCredentialsError, MethodCallError)
-        connector.disconnect()
-
-    def catch_all(failure):
-        on_message(failure.getTraceback(), error=True)
-        on_message("Unknown error occurred.", error=True)
-        return [2]
-
-    on_message("Please wait... ", "")
-
-    time.sleep(2)
-
-    def got_connection(remote):
-        handlers = {"registration-done": success,
-                    "registration-failed": failure,
-                    "exchange-failed": exchange_failure}
-        deferreds = [
-            remote.call_on_event(handlers),
-            remote.register().addErrback(handle_registration_errors)]
-        # We consume errors here to ignore errors after the first one.
-        # catch_all will be called for the very first deferred that fails.
-        results = gather_results(deferreds, consume_errors=True)
-        results.addErrback(catch_all)
-        results.addCallback(stop)
-
-    def got_error(failure):
-        on_message("There was an error communicating with the Landscape"
-                   " client.", error=True)
-        on_message("This machine will be registered with the provided "
-                   "details when the client runs.", error=True)
-        stop([2])
-
-    connector = RemoteBrokerConnector(reactor, config)
-    result = connector.connect(max_retries=max_retries, quiet=True)
-    result.addCallback(got_connection)
-    result.addErrback(got_error)
+    if results is None:
+        results = []
+    add_result = results.append
 
+    connector = connector_factory(reactor, config)
+    connection = connector.connect(max_retries=max_retries, quiet=True)
+    connection.addCallback(
+        partial(got_connection, add_result, connector, reactor))
+    connection.addErrback(got_error)
     reactor.run()
 
-    if exit_with_error:
-        on_error(exit_with_error[0])
+    assert len(results) == 1, "We expect exactly one result."
+    # Results will be things like "success" or "ssl-error".
+    result = results[0]
 
+    # If there was an error and the caller requested that errors be reported
+    # to the on_error callable, then do so.
+    if result != "success" and on_error is not None:
+        on_error(1)
     return result
 
 
-def main(args):
+def report_registration_outcome(what_happened, print=print):
+    """Report the registrtion interaction outcome to the user in human-readable
+    form.
+    """
+    if what_happened == "success":
+        print("System successfully registered.")
+    elif what_happened == "failure":
+        print("Invalid account name or registration key.", file=sys.stderr)
+    elif what_happened == "ssl-error":
+        print("\nThe server's SSL information is incorrect, or fails "
+              "signature verification!\n"
+              "If the server is using a self-signed certificate, "
+              "please ensure you supply it with the --ssl-public-key "
+              "parameter.", file=sys.stderr)
+    elif what_happened == "non-ssl-error":
+        print("\nWe were unable to contact the server.\n"
+              "Your internet connection may be down. "
+              "The landscape client will continue to try and contact "
+              "the server periodically.", file=sys.stderr)
+
+
+def determine_exit_code(what_happened):
+    """Return what the application's exit code should be depending on the
+    registration result.
+    """
+    if what_happened == "success":
+        return 0
+    else:
+        return 2  # An error happened
+
+
+def main(args, print=print):
+    """Interact with the user and the server to set up client configuration."""
+
     config = LandscapeSetupConfiguration()
     try:
         config.load(args)
@@ -708,11 +753,18 @@ def main(args):
         print_text(str(e))
         sys.exit("Aborting Landscape configuration")
 
+    print("Please wait...")
+
     # Attempt to register the client.
+    reactor = LandscapeReactor()
     if config.silent:
-        register(config)
+        result = register(config, reactor)
+        report_registration_outcome(result, print=print)
+        sys.exit(determine_exit_code(result))
     else:
         answer = raw_input("\nRequest a new registration for "
                            "this computer now? (Y/n): ")
         if not answer.upper().startswith("N"):
-            register(config)
+            result = register(config, reactor)
+            report_registration_outcome(result, print=print)
+            sys.exit(determine_exit_code(result))
