@@ -12,8 +12,8 @@ class ManagerConfigurationTest(LandscapeTest):
     def test_plugin_factories(self):
         """By default all plugins are enabled."""
         self.assertEqual(["ProcessKiller", "PackageManager", "UserManager",
-                          "ShutdownManager", "Eucalyptus", "AptSources",
-                          "HardwareInfo"],
+                          "ShutdownManager", "AptSources", "HardwareInfo",
+                          "KeystoneToken", "HAService"],
                          ALL_PLUGINS)
         self.assertEqual(ALL_PLUGINS, self.config.plugin_factories)
 
