@@ -10,7 +10,6 @@ from landscape.monitor.activeprocessinfo import ActiveProcessInfo
 from landscape.tests.helpers import (LandscapeTest, MonitorHelper,
                                      ProcessDataBuilder)
 from landscape.tests.mocker import ANY
-from landscape import SERVER_API
 
 
 class ActiveProcessInfoTest(LandscapeTest):
@@ -577,7 +576,7 @@ class ActiveProcessInfoTest(LandscapeTest):
         messages = self.mstore.get_pending_messages()
         self.assertEqual(len(messages), 2)
         self.assertMessages(messages, [{"timestamp": 0,
-                                        "api": SERVER_API,
+                                        "api": "3.2",
                                         "type": "active-process-info",
                                         "kill-all-processes": True,
                                         "add-processes": [{"start-time": 110,
@@ -589,7 +588,7 @@ class ActiveProcessInfoTest(LandscapeTest):
                                                             "vm-size": 11676,
                                                             "uid": 0}]},
                                        {"timestamp": 0,
-                                        "api": SERVER_API,
+                                        "api": "3.2",
                                         "type": "active-process-info",
                                         "update-processes": [
                                             {"start-time": 110,
