@@ -1,8 +1,11 @@
 import os
 import re
 
+from twisted.internet.defer import succeed, fail, inlineCallbacks
+
+from landscape.lib.fetch import HTTPCodeError, PyCurlError
 from landscape.lib.fs import create_file
-from landscape.monitor.computerinfo import ComputerInfo
+from landscape.monitor.computerinfo import ComputerInfo, METADATA_RETRY_MAX
 from landscape.tests.helpers import LandscapeTest, MonitorHelper
 from landscape.tests.mocker import ANY
 
@@ -49,10 +52,31 @@ VmallocChunk:   107432 kB
     def setUp(self):
         LandscapeTest.setUp(self)
         self.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
+        self.query_results = {}
+
+        def fetch_stub(url, **kwargs):
+            value = self.query_results[url]
+            if isinstance(value, Exception):
+                return fail(value)
+            else:
+                return succeed(value)
+
+        self.fetch_func = fetch_stub
+        self.add_query_result("instance-id", "i00001")
+        self.add_query_result("ami-id", "ami-00002")
+        self.add_query_result("instance-type", "hs1.8xlarge")
+
+    def add_query_result(self, name, value):
+        """
+        Add a url to self.query_results that is then available through
+        self.fetch_func.
+        """
+        url = "http://169.254.169.254/latest/meta-data/" + name
+        self.query_results[url] = value
 
     def test_get_fqdn(self):
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo(get_fqdn=get_fqdn)
+        plugin = ComputerInfo(get_fqdn=get_fqdn, fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -62,7 +86,7 @@ VmallocChunk:   107432 kB
 
     def test_get_real_hostname(self):
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -73,7 +97,7 @@ VmallocChunk:   107432 kB
 
     def test_only_report_changed_hostnames(self):
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo(get_fqdn=get_fqdn)
+        plugin = ComputerInfo(get_fqdn=get_fqdn, fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -91,7 +115,8 @@ VmallocChunk:   107432 kB
                 i = i + 1
 
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo(get_fqdn=hostname_factory().next)
+        plugin = ComputerInfo(get_fqdn=hostname_factory().next,
+                              fetch_async=self.fetch_func)
         self.monitor.add(plugin)
 
         plugin.exchange()
@@ -107,7 +132,8 @@ VmallocChunk:   107432 kB
     def test_get_total_memory(self):
         self.mstore.set_accepted_types(["computer-info"])
         meminfo_filename = self.makeFile(self.sample_memory_info)
-        plugin = ComputerInfo(meminfo_file=meminfo_filename)
+        plugin = ComputerInfo(meminfo_filename=meminfo_filename,
+                              fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -119,7 +145,7 @@ VmallocChunk:   107432 kB
     def test_get_real_total_memory(self):
         self.mstore.set_accepted_types(["computer-info"])
         self.makeFile(self.sample_memory_info)
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         message = self.mstore.get_pending_messages()[0]
@@ -129,7 +155,7 @@ VmallocChunk:   107432 kB
 
     def test_wb_report_changed_total_memory(self):
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
 
         plugin._get_memory_info = lambda: (1510, 1584)
@@ -146,7 +172,7 @@ VmallocChunk:   107432 kB
 
     def test_wb_report_changed_total_swap(self):
         self.mstore.set_accepted_types(["computer-info"])
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
 
         plugin._get_memory_info = lambda: (1510, 1584)
@@ -196,7 +222,7 @@ VmallocChunk:   107432 kB
         self.assertEqual(message["release"], "6.06")
         self.assertEqual(message["code-name"], "dapper")
 
-    def test_report_once(self):
+    def test_distribution_reported_only_once(self):
         """
         Distribution data shouldn't be reported unless it's changed
         since the last time it was reported.
@@ -208,7 +234,7 @@ VmallocChunk:   107432 kB
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
         self.assertEqual(len(messages), 1)
-        self.assertTrue(messages[0]["type"], "distribution-info")
+        self.assertEqual(messages[0]["type"], "distribution-info")
 
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -273,16 +299,18 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
         self.mstore.set_accepted_types(["distribution-info", "computer-info"])
         meminfo_filename = self.makeFile(self.sample_memory_info)
         plugin = ComputerInfo(get_fqdn=get_fqdn,
-                              meminfo_file=meminfo_filename,
+                              meminfo_filename=meminfo_filename,
                               lsb_release_filename=self.lsb_release_filename,
-                              root_path=self.makeDir())
+                              root_path=self.makeDir(),
+                              fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
-        self.reactor.fire("resynchronize")
+        self.reactor.fire("resynchronize", scopes=["computer"])
         plugin.exchange()
         computer_info = {"type": "computer-info", "hostname": "ooga.local",
                          "timestamp": 0, "total-memory": 1510,
                          "total-swap": 1584}
+
         dist_info = {"type": "distribution-info",
                      "code-name": "dapper", "description": "Ubuntu 6.06.1 LTS",
                      "distributor-id": "Ubuntu", "release": "6.06"}
@@ -291,11 +319,11 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
                              computer_info, dist_info])
 
     def test_computer_info_call_on_accepted(self):
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
 
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.replay()
 
         self.mstore.set_accepted_types(["computer-info"])
@@ -307,7 +335,7 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
         self.monitor.add(plugin)
 
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.replay()
 
         self.mstore.set_accepted_types(["distribution-info"])
@@ -330,14 +358,14 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
 
     def test_annotations(self):
         """
-        L{ComputerInfo} sends extra meta data the annotations.d directory
+        L{ComputerInfo} sends extra meta data from the annotations.d directory
         if it's present.
 
-        Each file name is used as a key in the annotations dict and
-        the file's contents are used as values.
+        Each file name is used as a key in the meta-data dict and the file's
+        contents are used as values.
 
-        This allows, for example, the landscape-client charm to send
-        information about the juju environment to the landscape server.
+        This allows system administrators to add extra per-computer information
+        into Landscape which makes sense to them.
         """
         annotations_dir = self.monitor.config.annotations_path
         os.mkdir(annotations_dir)
@@ -346,6 +374,7 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
         self.mstore.set_accepted_types(["computer-info"])
 
         plugin = ComputerInfo()
+        plugin._cloud_meta_data = {}
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -355,34 +384,117 @@ DISTRIB_NEW_UNEXPECTED_KEY=ooga
         self.assertEqual("value1", meta_data["annotation1"])
         self.assertEqual("value2", meta_data["annotation2"])
 
-    def test_annotations_no_directory(self):
+    def test_fetch_cloud_metadata(self):
         """
-        L{ComputerInfo} doesn't include the annotations key if there
-        is no annotations.d directory.
+        Fetch cloud information and insert it in a cloud-instance-metadata
+        message.
         """
-        meta_data_dir = self.monitor.config.annotations_path
-        self.assertFalse(os.path.exists(meta_data_dir))
-        self.mstore.set_accepted_types(["computer-info"])
+        self.config.cloud = True
+        self.mstore.set_accepted_types(["cloud-instance-metadata"])
 
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
         self.assertEqual(1, len(messages))
-        self.assertNotIn("annotations", messages[0])
+        self.assertEqual(u"i00001", messages[0]["instance-id"])
+        self.assertEqual(u"ami-00002", messages[0]["ami-id"])
+        self.assertEqual(u"hs1.8xlarge", messages[0]["instance-type"])
 
-    def test_extra_meta_data_empty_directory(self):
-        """
-        L{ComputerInfo} doesn't include the annotations key if the
-        annotations.d directory doesn't contain any files.
-        """
-        meta_data_dir = self.monitor.config.annotations_path
-        os.mkdir(meta_data_dir)
-        self.mstore.set_accepted_types(["computer-info"])
+    def test_send_cloud_instance_metadata_only_once(self):
+        """Only send the cloud information once per client restart."""
+        self.config.cloud = True
+        self.mstore.set_accepted_types(["cloud-instance-metadata"])
 
-        plugin = ComputerInfo()
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
         self.monitor.add(plugin)
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
         self.assertEqual(1, len(messages))
-        self.assertNotIn("annotations", messages[0])
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual(1, len(messages))
+
+    def test_no_fetch_ec2_meta_data_when_cloud_retries_is_max(self):
+        """
+        Do not fetch EC2 info when C{_cloud_retries} is C{METADATA_RETRY_MAX}
+        """
+        self.config.cloud = True
+        self.mstore.set_accepted_types(["cloud-instance-metadata"])
+
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
+        plugin._cloud_retries = METADATA_RETRY_MAX
+        self.monitor.add(plugin)
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual(0, len(messages))
+
+    @inlineCallbacks
+    def test_fetch_ec2_meta_data(self):
+        """
+        L{_fetch_ec2_meta_data} retrieves instance information from the
+        EC2 api.
+        """
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
+        result = yield plugin._fetch_ec2_meta_data()
+        self.assertEqual({"instance-id": u"i00001", "ami-id": u"ami-00002",
+                          "instance-type": u"hs1.8xlarge"}, result)
+        self.assertEqual(
+            "    INFO: Querying cloud meta-data.\n"
+            "    INFO: Acquired cloud meta-data.\n",
+            self.logfile.getvalue())
+
+    @inlineCallbacks
+    def test_fetch_ec2_meta_data_no_cloud_api_max_retry(self):
+        """
+        L{_fetch_ec2_meta_data} returns C{None} when faced with no EC2 cloud
+        API service and reports the specific C{PyCurlError} upon message
+        exchange when L{_cloud_retries} equals C{METADATA_RETRY_MAX}.
+        """
+        self.log_helper.ignore_errors(PyCurlError)
+        self.add_query_result("instance-id", PyCurlError(60, "pycurl error"))
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
+        plugin._cloud_retries = METADATA_RETRY_MAX
+        result = yield plugin._fetch_ec2_meta_data()
+        self.assertIn(
+            "INFO: No cloud meta-data available. "
+            "Error 60: pycurl error\n", self.logfile.getvalue())
+        self.assertEqual(None, result)
+
+    @inlineCallbacks
+    def test_fetch_ec2_meta_data_bad_result_max_retry(self):
+        """
+        L{_fetch_ec2_meta_data} returns C{None} and logs an error when
+        crossing the retry threshold C{METADATA_RETRY_MAX}.
+        """
+        self.log_helper.ignore_errors(HTTPCodeError)
+        self.add_query_result("ami-id", HTTPCodeError(404, "notfound"))
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
+        plugin._cloud_retries = METADATA_RETRY_MAX
+        result = yield plugin._fetch_ec2_meta_data()
+        self.assertIn(
+            "INFO: No cloud meta-data available. Server returned "
+            "HTTP code 404",
+            self.logfile.getvalue())
+        self.assertEqual(None, result)
+
+    @inlineCallbacks
+    def test_fetch_ec2_meta_data_bad_result_retry(self):
+        """
+        L{_fetch_ec2_meta_data} returns C{None} when faced with spurious
+        errors from the EC2 api. The method increments L{_cloud_retries}
+        counter which allows L{_fetch_ec2_meta_data} to run again next
+        message exchange.
+        """
+        self.log_helper.ignore_errors(HTTPCodeError)
+        self.add_query_result("ami-id", HTTPCodeError(404, "notfound"))
+        plugin = ComputerInfo(fetch_async=self.fetch_func)
+        result = yield plugin._fetch_ec2_meta_data()
+        self.assertEqual(1, plugin._cloud_retries)
+        self.assertEqual(None, result)
+        # Fix the error condition for the retry.
+        self.add_query_result("ami-id", "ami-00002")
+        result = yield plugin._fetch_ec2_meta_data()
+        self.assertEqual({"instance-id": u"i00001", "ami-id": u"ami-00002",
+                          "instance-type": u"hs1.8xlarge"},
+                         result)
