@@ -1,5 +1,6 @@
 from landscape.tests.helpers import LandscapeTest, MonitorHelper
-from landscape.lib.network import get_active_device_info
+from landscape.lib.network import (
+    get_active_device_info)
 from landscape.monitor.networkdevice import NetworkDevice
 
 
@@ -23,7 +24,7 @@ class NetworkDeviceTest(LandscapeTest):
         """A message is sent with device info"""
         self.plugin.exchange()
         message = self.mstore.get_pending_messages()[0]
-        self.assertEquals(message["type"], "network-device")
+        self.assertEqual(message["type"], "network-device")
         self.failUnlessIn("devices", message)
         self.assertTrue(len(message["devices"]))
         # only network device we can truly assert is localhost
@@ -31,9 +32,9 @@ class NetworkDeviceTest(LandscapeTest):
         self.assertTrue(message["devices"][0]["ip_address"], "0.0.0.0")
         self.assertTrue(message["devices"][0]["netmask"], "255.0.0.0")
         flags = message["devices"][0]["flags"]
-        self.assertEqual(1, flags & 1) # UP
-        self.assertEqual(8, flags & 8) # LOOPBACK
-        self.assertEqual(64, flags & 64) # RUNNING
+        self.assertEqual(1, flags & 1)  # UP
+        self.assertEqual(8, flags & 8)  # LOOPBACK
+        self.assertEqual(64, flags & 64)  # RUNNING
 
     def test_no_message_with_no_changes(self):
         """If no device changes from the last message, no message is sent."""
