@@ -65,6 +65,47 @@ class MonitorPluginTest(LandscapeTest):
         plugin.call_on_accepted("type", callback)
         self.reactor.fire(("message-type-acceptance-changed", "type"), False)
 
+    def test_resynchronize_with_global_scope(self):
+        """
+        If a 'resynchronize' event fires with global scope, we clear down the
+        persist.
+        """
+        plugin = MonitorPlugin()
+        plugin.persist_name = "wubble"
+        plugin.register(self.monitor)
+        plugin.persist.set("hi", "there")
+        self.assertEqual(self.monitor.persist.get("wubble"), {"hi": "there"})
+        self.reactor.fire("resynchronize")
+        self.assertTrue(self.monitor.persist.get("wubble") is None)
+
+    def test_resynchronize_with_provided_scope(self):
+        """
+        If a 'resynchronize' event fires with the provided scope, we clear down
+        the persist.
+        """
+        plugin = MonitorPlugin()
+        plugin.persist_name = "wubble"
+        plugin.scope = "frujical"
+        plugin.register(self.monitor)
+        plugin.persist.set("hi", "there")
+        self.assertEqual(self.monitor.persist.get("wubble"), {"hi": "there"})
+        self.reactor.fire("resynchronize", scopes=["frujical"])
+        self.assertTrue(self.monitor.persist.get("wubble") is None)
+
+    def test_do_not_resynchronize_with_other_scope(self):
+        """
+        If a 'resynchronize' event fires with an irrelevant scope, we do
+        nothing.
+        """
+        plugin = MonitorPlugin()
+        plugin.persist_name = "wubble"
+        plugin.scope = "frujical"
+        plugin.register(self.monitor)
+        plugin.persist.set("hi", "there")
+        self.assertEqual(self.monitor.persist.get("wubble"), {"hi": "there"})
+        self.reactor.fire("resynchronize", scopes=["chrutfup"])
+        self.assertEqual(self.monitor.persist.get("wubble"), {"hi": "there"})
+
 
 class StubDataWatchingPlugin(DataWatcher):
 
@@ -123,7 +164,7 @@ class DataWatcherTest(LandscapeTest):
         make sure it sends the message urgently.
         """
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.result(succeed(None))
         self.mocker.replay()
 
