@@ -23,7 +23,6 @@ from apt.progress.text import AcquireProgress
 from apt.progress.base import InstallProgress
 
 from landscape.lib.fs import append_file, create_file, read_file, touch_file
-from landscape.constants import UBUNTU_PATH
 from landscape.package.skeleton import build_skeleton_apt
 
 
@@ -592,23 +591,11 @@ class AptFacade(object):
         os.environ["APT_LISTCHANGES_FRONTEND"] = "none"
         os.environ["APT_LISTBUGS_FRONTEND"] = "none"
 
-    def _default_path_when_missing(self):
-        """
-        If no PATH is set in the environment, use the Ubuntu default PATH.
-
-        When the client is launched from the landscape-client-settings-ui the
-        PATH variable is incorrectly set, this method rectifies that.
-        """
-        # dpkg will fail if no path is set.
-        if "PATH" not in os.environ:
-            os.environ["PATH"] = UBUNTU_PATH
-
     def _setup_dpkg_for_changes(self):
         """
         Setup environment and apt options for successful package operations.
         """
         self._set_frontend_noninteractive()
-        self._default_path_when_missing()
         apt_pkg.config.clear("DPkg::options")
         apt_pkg.config.set("DPkg::options::", "--force-confold")
 
@@ -675,12 +662,16 @@ class AptFacade(object):
                         install_progress=install_progress)
                     if not install_progress.dpkg_exited:
                         raise SystemError("dpkg didn't exit cleanly.")
-                except (apt.cache.LockFailedException, SystemError), error:
+                except (apt.cache.LockFailedException, SystemError), exception:
                     result_text = (fetch_output.getvalue()
                                    + read_file(install_output_path))
-                    error = TransactionError(error.args[0] +
+                    error = TransactionError(exception.args[0] +
                                              "\n\nPackage operation log:\n" +
                                              result_text)
+                    if isinstance(exception, SystemError):
+                        # No need to retry SystemError, since it's most
+                        # likely a permanent error.
+                        break
                 else:
                     result_text = (fetch_output.getvalue()
                                    + read_file(install_output_path))
