@@ -12,11 +12,11 @@ class LandscapeLinkTest(LandscapeTest):
         self.sysinfo.add(self.landscape_link)
 
     def test_run_returns_succeeded_deferred(self):
-        self.assertDeferredSucceeded(self.landscape_link.run())
+        self.assertIs(None, self.successResultOf(self.landscape_link.run()))
 
     def test_run_adds_footnote(self):
         self.landscape_link.run()
         self.assertEqual(
             self.sysinfo.get_footnotes(),
-            ["Graph this data and manage this system at "
-             "https://landscape.canonical.com/"])
+            ["Graph this data and manage this system at:\n"
+             "    https://landscape.canonical.com/"])
