@@ -1,7 +1,4 @@
-try:
-    from pysqlite2 import dbapi2 as sqlite3
-except:
-    import sqlite3
+import sqlite3
 
 from landscape.lib.persist import Persist
 from landscape.patch import UpgradeManager, SQLiteUpgradeManager
@@ -20,16 +17,16 @@ class PatchTest(LandscapeTest):
         Applying no patches should make no change to the database,
         apart from maybe specifying a default version.
         """
-        self.assertEquals(self.persist._hardmap, {})
+        self.assertEqual(self.persist._hardmap, {})
         self.manager.apply(self.persist)
-        self.assertEquals(self.persist._hardmap, {"system-version": 0})
+        self.assertEqual(self.persist._hardmap, {"system-version": 0})
 
     def test_one_patch(self):
         """Test that patches are called and passed a L{Persist} object."""
         l = []
         self.manager.register_upgrader(1, l.append)
         self.manager.apply(self.persist)
-        self.assertEquals(l, [self.persist])
+        self.assertEqual(l, [self.persist])
 
     def test_two_patches(self):
         """Test that patches are run in order."""
@@ -38,14 +35,14 @@ class PatchTest(LandscapeTest):
         self.manager.register_upgrader(1, lambda x: l.append(1))
 
         self.manager.apply(self.persist)
-        self.assertEquals(l, [1, 2])
+        self.assertEqual(l, [1, 2])
 
     def test_record_version(self):
         """When a patch is run it should update the C{system-version}."""
-        self.assertEquals(self.persist.get("system-version"), None)
+        self.assertEqual(self.persist.get("system-version"), None)
         self.manager.register_upgrader(1, lambda x: None)
         self.manager.apply(self.persist)
-        self.assertEquals(self.persist.get("system-version"), 1)
+        self.assertEqual(self.persist.get("system-version"), 1)
 
     def test_only_apply_unapplied_versions(self):
         """Upgraders should only be run if they haven't been run before."""
@@ -53,12 +50,12 @@ class PatchTest(LandscapeTest):
         self.manager.register_upgrader(1, lambda x: l.append(1))
         self.manager.apply(self.persist)
         self.manager.apply(self.persist)
-        self.assertEquals(l, [1])
+        self.assertEqual(l, [1])
 
     def test_initialize(self):
         """Marking no upgraders as applied should leave the version at 0."""
         self.manager.initialize(self.persist)
-        self.assertEquals(self.persist.get("system-version"), 0)
+        self.assertEqual(self.persist.get("system-version"), 0)
 
     def test_initialize_with_upgraders(self):
         """
@@ -66,12 +63,12 @@ class PatchTest(LandscapeTest):
         version for the new persist to the highest version number
         available, without running any of the upgraders.
         """
-        self.manager.register_upgrader(1, lambda x: 1/0)
-        self.manager.register_upgrader(5, lambda x: 1/0)
-        self.manager.register_upgrader(3, lambda x: 1/0)
+        self.manager.register_upgrader(1, lambda x: 1 / 0)
+        self.manager.register_upgrader(5, lambda x: 1 / 0)
+        self.manager.register_upgrader(3, lambda x: 1 / 0)
         self.manager.initialize(self.persist)
 
-        self.assertEquals(self.persist.get("system-version"), 5)
+        self.assertEqual(self.persist.get("system-version"), 5)
 
     def test_decorated_upgraders_run(self):
         """
@@ -80,6 +77,7 @@ class PatchTest(LandscapeTest):
         L{UpgradeManager} and be run when the manager applies patches.
         """
         upgrade_manager = UpgradeManager()
+
         @upgrade_manager.upgrader(1)
         def upgrade(persist):
             self.persist.set("upgrade-called", True)
@@ -105,8 +103,8 @@ class SQLitePatchTest(LandscapeTest):
         """
         self.manager.initialize(self.cursor)
         self.manager.apply(self.cursor)
-        self.assertEquals(self.manager.get_database_versions(self.cursor),
-                          set())
+        self.assertEqual(self.manager.get_database_versions(self.cursor),
+                         set())
 
     def test_one_patch(self):
         """Test that patches are called and passed a sqlite db object."""
@@ -114,9 +112,9 @@ class SQLitePatchTest(LandscapeTest):
         self.manager.initialize(self.cursor)
         self.manager.register_upgrader(1, l.append)
         self.manager.apply(self.cursor)
-        self.assertEquals(l, [self.cursor])
+        self.assertEqual(l, [self.cursor])
         self.cursor.execute(self.version_query)
-        self.assertEquals(self.cursor.fetchone(), (1,))
+        self.assertEqual(self.cursor.fetchone(), (1,))
 
     def test_two_patches(self):
         """Test that patches are run in order."""
@@ -126,9 +124,9 @@ class SQLitePatchTest(LandscapeTest):
         self.manager.register_upgrader(1, lambda x: l.append(1))
 
         self.manager.apply(self.cursor)
-        self.assertEquals(l, [1, 2])
+        self.assertEqual(l, [1, 2])
         self.cursor.execute(self.version_query)
-        self.assertEquals(self.cursor.fetchone(), (2,))
+        self.assertEqual(self.cursor.fetchone(), (2,))
 
     def test_only_apply_unapplied_versions(self):
         """Upgraders should only be run if they haven't been run before."""
@@ -140,9 +138,9 @@ class SQLitePatchTest(LandscapeTest):
         self.manager.register_upgrader(2, lambda x: patch2.append(1))
         self.manager.register_upgrader(3, lambda x: patch3.append(1))
         self.manager.apply_one(2, self.cursor)
-        self.assertEquals((patch1, patch2, patch3), ([], [1], []))
+        self.assertEqual((patch1, patch2, patch3), ([], [1], []))
         self.manager.apply(self.cursor)
-        self.assertEquals((patch1, patch2, patch3), ([1], [1], [1]))
+        self.assertEqual((patch1, patch2, patch3), ([1], [1], [1]))
 
     def test_initialize_with_upgraders(self):
         """
@@ -150,12 +148,12 @@ class SQLitePatchTest(LandscapeTest):
         version of the newly created database to the highest version
         available.
         """
-        self.manager.register_upgrader(1, lambda x: 1/0)
-        self.manager.register_upgrader(5, lambda x: 1/0)
-        self.manager.register_upgrader(3, lambda x: 1/0)
+        self.manager.register_upgrader(1, lambda x: 1 / 0)
+        self.manager.register_upgrader(5, lambda x: 1 / 0)
+        self.manager.register_upgrader(3, lambda x: 1 / 0)
         self.manager.initialize(self.cursor)
-        self.assertEquals(self.manager.get_database_versions(self.cursor),
-                          set([1, 3, 5]))
+        self.assertEqual(self.manager.get_database_versions(self.cursor),
+                         set([1, 3, 5]))
 
     def test_decorated_upgraders_run(self):
         """
@@ -166,9 +164,10 @@ class SQLitePatchTest(LandscapeTest):
         upgrade_manager = SQLiteUpgradeManager()
         upgrade_manager.initialize(self.cursor)
         l = []
+
         @upgrade_manager.upgrader(1)
         def upgrade(db):
             l.append(db)
 
         upgrade_manager.apply(self.cursor)
-        self.assertEquals(l, [self.cursor])
+        self.assertEqual(l, [self.cursor])
