@@ -19,12 +19,8 @@ from landscape.watchdog import (
     WatchDogConfiguration, bootstrap_list,
     MAXIMUM_CONSECUTIVE_RESTARTS, RESTART_BURST_DELAY, run,
     Broker, Monitor, Manager)
-from landscape.lib.dns import discover_server
-from landscape.configuration import (
-    fetch_base64_ssl_public_certificate, print_text)
 from landscape.amp import ComponentConnector
 from landscape.broker.amp import RemoteBrokerConnector
-from landscape.deployment import Configuration
 from landscape.reactor import LandscapeReactor
 
 import landscape.watchdog
@@ -1193,154 +1189,6 @@ class WatchDogServiceTest(LandscapeTest):
         self.assertEqual(service.exit_code, 2)
         return result
 
-    def test_autodiscover_config_write_with_pubkey(self):
-        """
-        When server_autodiscover is set True, and the config.ssl_public_key
-        already exists, ensure we update and write the config file with the
-        discovered server urls.
-        """
-        self.configuration.server_autodiscover = True
-        self.configuration.ssl_public_key = "/tmp/fakepubkey.ssl"
-
-        service = WatchDogService(self.configuration)
-
-        # Validate appropriate initial config options
-        self.assertEquals("https://landscape.canonical.com/message-system",
-                          service._config.url)
-        self.assertEquals("/tmp/fakepubkey.ssl",
-                          service._config.ssl_public_key)
-        self.assertTrue(service._config.server_autodiscover)
-
-        bootstrap_list_mock = self.mocker.patch(bootstrap_list)
-        bootstrap_list_mock.bootstrap(data_path=self.data_path,
-                                      log_dir=self.log_dir)
-
-        self.mocker.order()
-
-        discover_mock = self.mocker.replace(discover_server, passthrough=False)
-        discover_mock(self.configuration.autodiscover_srv_query_string,
-                      self.configuration.autodiscover_a_query_string)
-        self.mocker.result(succeed("fakehostname"))
-
-        watchdog_mock = self.mocker.replace(service.watchdog)
-        watchdog_mock.check_running()
-        self.mocker.result(succeed([]))
-        watchdog_mock.start()
-        self.mocker.result(succeed(None))
-        self.mocker.replay()
-
-        # trigger something to ensure autodiscover() is called
-        service.startService()
-
-        # Reload config to validate config.write() was called with changes
-        config = Configuration()
-        config.load(["--config", self.config_filename])
-        self.assertFalse(config.server_autodiscover)
-        self.assertEquals("https://fakehostname/message-system",
-                         config.url)
-        self.assertEquals("http://fakehostname/ping",
-                         config.ping_url)
-        self.assertEquals("/tmp/fakepubkey.ssl", config.ssl_public_key)
-
-    def test_autodiscover_config_write_without_pubkey(self):
-        """
-        WatchDogService should attempt to fetch the custom CA cert from the
-        discovered server if server_autodiscover=True and ssl_public_key is
-        undefined. If the discovered server has a custom signed CA cert, that
-        should be saved and its file path should be written to to configuration
-        file.
-        """
-        base64_cert = "base64:  MTIzNDU2Nzg5MA=="  # encoded from 1234567890
-
-        key_filename = os.path.join(self.data_path,
-            os.path.basename(self.config_filename + ".ssl_public_key"))
-
-        self.configuration.server_autodiscover = True
-
-        service = WatchDogService(self.configuration)
-
-        # Validate appropriate initial config options
-        self.assertEquals(None, self.configuration.ssl_public_key)
-        self.assertTrue(self.configuration.server_autodiscover)
-
-        discover_mock = self.mocker.replace(discover_server, passthrough=False)
-        discover_mock(self.configuration.autodiscover_srv_query_string,
-                      self.configuration.autodiscover_a_query_string)
-        self.mocker.result(succeed("fakehostname"))
-
-        fetch_ca_mock = self.mocker.replace(
-            fetch_base64_ssl_public_certificate, passthrough=False)
-
-        fetch_ca_mock("fakehostname", on_info=ANY, on_error=ANY)
-        self.mocker.result(base64_cert)
-
-        print_text_mock = self.mocker.replace(print_text)
-        print_text_mock("Writing SSL CA certificate to %s..." % key_filename)
-
-        watchdog_mock = self.mocker.replace(service.watchdog)
-        watchdog_mock.check_running()
-        self.mocker.result(succeed([]))
-        watchdog_mock.start()
-        self.mocker.result(succeed(None))
-        self.mocker.replay()
-
-        service.startService()
-
-        # Reload config file to validate config.write() was called with changes
-        config = Configuration()
-        config.load(["--config", self.config_filename])
-        self.assertFalse(config.server_autodiscover)
-        self.assertEquals("https://fakehostname/message-system",
-                         config.url)
-        self.assertEquals("http://fakehostname/ping",
-                         config.ping_url)
-        self.assertEquals(key_filename, config.ssl_public_key)
-        self.assertEqual("1234567890", open(key_filename, "r").read())
-
-    def test_autodiscover_config_write_without_pubkey_no_custom_ca(self):
-        """
-        When server_autodiscover is set True, and the config does not have an
-        ssl_public_key defined WatchDogService should attempt to fetch the
-        custom CA cert from the discovered server.
-        """
-        self.configuration.server_autodiscover = True
-
-        service = WatchDogService(self.configuration)
-
-        # Validate appropriate initial config options
-        self.assertEquals(None, self.configuration.ssl_public_key)
-        self.assertTrue(self.configuration.server_autodiscover)
-
-        discover_mock = self.mocker.replace(discover_server, passthrough=False)
-        discover_mock(self.configuration.autodiscover_srv_query_string,
-                      self.configuration.autodiscover_a_query_string)
-        self.mocker.result(succeed("fakehostname"))
-
-        fetch_ca_mock = self.mocker.replace(
-            fetch_base64_ssl_public_certificate, passthrough=False)
-
-        fetch_ca_mock("fakehostname", on_info=ANY, on_error=ANY)
-        self.mocker.result("")  # No Custom CA cert found
-
-        watchdog_mock = self.mocker.replace(service.watchdog)
-        watchdog_mock.check_running()
-        self.mocker.result(succeed([]))
-        watchdog_mock.start()
-        self.mocker.result(succeed(None))
-        self.mocker.replay()
-
-        service.startService()
-
-        # Reload config file to validate config.write() was called with changes
-        config = Configuration()
-        config.load(["--config", self.config_filename])
-        self.assertFalse(config.server_autodiscover)
-        self.assertEquals("https://fakehostname/message-system",
-                         config.url)
-        self.assertEquals("http://fakehostname/ping",
-                         config.ping_url)
-        self.assertEquals(None, config.ssl_public_key)
-
     def test_bootstrap(self):
 
         data_path = self.makeDir()
